@@ -1,4 +1,5 @@
-package TestApp;
+package # hide from PAUSE
+    TestApp;
 
 use strict;
 use warnings;
@@ -16,6 +17,10 @@ __PACKAGE__->config(
         },
 );
 
+if ($::use_root_string) {
+    __PACKAGE__->config(root => __PACKAGE__->config->{root}->stringify);
+}
+
 __PACKAGE__->setup;
 
 sub test : Local {
